/*
 * Svjatoslav Commons - shared library of common functionality. Author: Svjatoslav Agejenko.
 * This project is released under Creative Commons Zero (CC0) license.
 */
package eu.svjatoslav.commons.cli_helper.parameter_parser.parameter;

import eu.svjatoslav.commons.cli_helper.parameter_parser.ArgumentCount;
import eu.svjatoslav.commons.cli_helper.parameter_parser.Parameter;

public class IntegerParameter extends Parameter<Integer, IntegerParameter> {

    public IntegerParameter(final String description) {
        super(description, ArgumentCount.SINGLE);
    }

    @Override
    public java.lang.String describeFormat() {
        return "integer";
    }

    @Override
    public Integer getValue() {
        if (arguments.size() != 1)
            throw new RuntimeException("Parameter " + description
                    + " shall have exactly 1 argument.");
        return Integer.parseInt(arguments.get(0));
    }

    @Override
    public boolean validate(final java.lang.String value) {
        try {
            java.lang.Integer.valueOf(value);
            return true;
        } catch (final NumberFormatException e) {
            return false;
        }
    }
}
